<?php

namespace Celebrio\FileSystem\Drivers;

use Nette\Object;
use \DibiFluent;
use \dibi;

use Celebrio\FileSystem\GenericFile;
use Celebrio\FileSystem\DataFile;
use Celebrio\FileSystem\VirtualFile;
use \InvalidArgumentException;


class AzureCelebrioDatabase extends Object {
    
    
    
    public function getOwner(DataFile $dataFile) {
        $name = $dataFile->getName();
        $url = "root" . $dataFile->getUrl();
        
        $owner = dibi::query("SELECT [user_name] FROM [users] JOIN [files] 
            ON [id] = [id_user] WHERE name_file=%s AND url=%s", $name, $url)->fetch();
                
       return $owner["user_name"];
        
    }
    
    /**
     * 
     * 
     * @param DataFile $dataFile
     * @param bool $id when is true, function returns name and id insted of name.
     * @return string $result name 
     */
    public function getOrMakeRemoteName(DataFile $dataFile) {
        $name = $dataFile->getName();
        $url = "root" . $dataFile->getUrl();
        $azureName = dibi::fetchSingle("SELECT [name_azure_file] 
            FROM [azure_files] JOIN [files]
            ON [azure_files.id_file] = [files.id_file] 
            WHERE name_file=%s AND url=%s", $name, $url);
        
        if(!$azureName) {
            $id = $this->getFileId($dataFile);
            $azureName = \sha1($id . $url . $name);
            
            $args = array(
                "id_file" => $id,
                "name_azure_file" => $azureName
            );
            dibi::query("INSERT INTO [azure_files]", $args);
        }
        
        return $azureName;
    }
    
    private function getFileId(DataFile $dataFile) {
        $result = dibi::select("id_file")
                        ->from("files")
                        ->where("name_file=%s and url=%s", 
                                $dataFile->getName(), 
                                "root" . $dataFile->getUrl())
                        ->fetchSingle();
        
        if(!$result) {
            throw new InvalidArgumentException("This file does not exist");
        } else {
            return $result;
        }
    }
}
