<?php

/**
 * Description of AzureCelebInit
 *
 * @author honza
 */

namespace Celebrio\FileSystem\Drivers;

use Nette\Object;
use \dibi;

use Celebrio\Core\IModuleInit;
use Celebrio\Core\ConfigManagement;
use Celebrio\Core\DDL;
use Celebrio\FileSystem\Drivers\AzureStorageDriver;
use Celebrio\Core\ServiceProvider;


class AzureCelebrioInit extends Object implements IModuleInit {
    
    public function changeConfig(array $configuration) {
        return $configuration;
    }


    public function init(array $configuration) {
        $host = $configuration["host"];
        $accountName = $configuration["accountName"];
        $password = $configuration["password"];
        AzureCelebrio::setConnectionSettings($host, $accountName, $password);
    }

    public function install(array $configuration) {
        $dbDriver = ServiceProvider::getService("Celebrio-Database-IDatabase");
        $dbName = $dbDriver->getReflection()->getName();
        $dbName = \explode("\\", $dbName);
        $dbName = $dbName[\count($dbName)-1];
        DDL::execute(__DIR__ . "/initScripts/Azure-$dbName.sql");
        $this->initDriverStorage();
        
    }

    public function isAvailable() {
        return true;
    }
    
    public function formFields() {
        return array(
            array(
                "name" => "host", 
                "label" => "Host:", 
                "type" => "text", 
                "required" => _('Please provide a host.')
            ),
            array(
                "name" => "accountName", 
                "label" => "Account name:", 
                "type" => "text", 
                "required" => _('Please provide a account name.')
            ),
            array(
                "name" => "password", 
                "label" => "Password:", 
                "type" => "password", 
                "required" => _('Please provide a password.')
            )
            
        );
    }
    
    private function initDriverStorage() {
        $exists = dibi::fetch("
            SELECT [id_files_storage] 
            FROM [files_storages]
            WHERE [name_files_storage] = %s", "azureCelebrio");
        
        if(!$exists) {
            dibi::query("
                INSERT INTO [files_storages]
                ([name_files_storage]) VALUES (%s)", "azureCelebrio");
        }
    }

}
