-- Create tables section -------------------------------------------------

-- Table users already created
-- Table roles already created

-- Table files

CREATE TABLE "files"(
 "id_file" Serial NOT NULL,
 "id_user" Integer,
 "id_mimetype" Integer NOT NULL,
 "url" Character varying(255),
 "name_file" Character varying(255) NOT NULL,
 "hidden" Boolean DEFAULT false NOT NULL,
 "protected" Boolean DEFAULT false NOT NULL,
 "encrypted" Boolean DEFAULT false NOT NULL,
 "locked" Integer,
 "deleted" Boolean DEFAULT false NOT NULL,
 "id_parent" Integer,
 "hash" Character(128),
 "id_files_storage" Integer NOT NULL
)
WITH (OIDS=FALSE)
;

-- Add keys for table files

ALTER TABLE "files" ADD CONSTRAINT "files_pk" PRIMARY KEY ("id_file")
;

-- Table fpermissions

CREATE TABLE "fpermissions"(
 "id_file" Integer NOT NULL,
 "id_role" Integer NOT NULL,
 "id_fprivilege" Integer NOT NULL,
 "allowed" Boolean DEFAULT true NOT NULL
)
WITH (OIDS=FALSE)
;

-- Add keys for table fpermissions

ALTER TABLE "fpermissions" ADD CONSTRAINT "Key4" PRIMARY KEY ("id_fprivilege","id_role","id_file")
;

-- Table fprivileges

CREATE TABLE "fprivileges"(
 "id_fprivilege" Serial NOT NULL,
 "name" Character varying(255) UNIQUE NOT NULL
)
WITH (OIDS=FALSE)
;

-- Add keys for table fprivileges

ALTER TABLE "fprivileges" ADD CONSTRAINT "fprivileges_pk" PRIMARY KEY ("id_fprivilege")
;

-- Table mimetypes

CREATE TABLE "mimetypes"(
 "id_mimetype" Serial NOT NULL,
 "name_mimetype" Character varying(40)
)
WITH (OIDS=FALSE)
;

-- Add keys for table mimetypes

ALTER TABLE "mimetypes" ADD CONSTRAINT "mimetypes_pk" PRIMARY KEY ("id_mimetype")
;

-- Table actions

CREATE TABLE "actions"(
 "id_action" Serial NOT NULL,
 "name" Character varying(40)
)
WITH (OIDS=FALSE)
;

-- Add keys for table actions

ALTER TABLE "actions" ADD CONSTRAINT "actions_pk" PRIMARY KEY ("id_action")
;

-- Table applications

CREATE TABLE "applications"(
 "id_application" Serial NOT NULL,
 "url" Character(255),
 "name" Character varying(40),
 "publisher" Character varying(100),
 "altText" Character varying(40),
 "created" Timestamp NOT NULL,
 "version" Character varying(12),
 "system" Boolean DEFAULT false NOT NULL
)
WITH (OIDS=FALSE)
;

-- Add keys for table applications

ALTER TABLE "applications" ADD CONSTRAINT "applications_pk" PRIMARY KEY ("id_application")
;
ALTER TABLE "applications" ADD CONSTRAINT "url" UNIQUE ("url")
;
ALTER TABLE "applications" ADD CONSTRAINT "name" UNIQUE ("name")
;


-- Table applications_users

CREATE TABLE "applications_users"(
 "id_application" Integer NOT NULL,
 "id_user" Integer NOT NULL
)
WITH (OIDS=FALSE)
;

-- Add keys for table applications_users

ALTER TABLE "applications_users" ADD CONSTRAINT "Key10" PRIMARY KEY ("id_application","id_user")
;

-- Table file_preferences

CREATE TABLE "file_preferences"(
 "id_action" Integer NOT NULL,
 "id_mimetype" Integer NOT NULL,
 "id_application" Integer NOT NULL,
 "id_user" Integer NOT NULL
)
WITH (OIDS=FALSE)
;

-- Add keys for table file_preferences

ALTER TABLE "file_preferences" ADD CONSTRAINT "Key9" PRIMARY KEY ("id_action","id_mimetype","id_application","id_user")
;

-- Table file_changes

CREATE TABLE "file_changes"(
 "id_file_change" Serial NOT NULL,
 "id_file" Integer,
 "time" Timestamp,
 "action" Smallint,
 "id_user" Integer,
 "name_file" Character varying(255) NOT NULL,
 "user_name" Character varying(45) NOT NULL
)
WITH (OIDS=FALSE)
;

-- Table files_storages

CREATE TABLE "files_storages"(
 "id_files_storage" Serial NOT NULL,
 "name_files_storage" Character varying(255)
)
WITH (OIDS=FALSE)
;

ALTER TABLE "files_storages" ADD CONSTRAINT "id_files_storage" PRIMARY KEY ("id_files_storage")
;

-- Add keys for table file_changes

ALTER TABLE "file_changes" ADD CONSTRAINT "files_changes_pk" PRIMARY KEY ("id_file_change")
;

-- Create relationships section ------------------------------------------------- 

ALTER TABLE "files" ADD CONSTRAINT "users_files" FOREIGN KEY ("id_user") REFERENCES "users" ("id") ON DELETE SET NULL ON UPDATE CASCADE
;

ALTER TABLE "fpermissions" ADD CONSTRAINT "files_fpermissions" FOREIGN KEY ("id_file") REFERENCES "files" ("id_file") ON DELETE CASCADE ON UPDATE CASCADE
;

ALTER TABLE "fpermissions" ADD CONSTRAINT "roles_fpermissions" FOREIGN KEY ("id_role") REFERENCES "roles" ("id") ON DELETE CASCADE ON UPDATE CASCADE
;

ALTER TABLE "fpermissions" ADD CONSTRAINT "fprivileges_fpermissions" FOREIGN KEY ("id_fprivilege") REFERENCES "fprivileges" ("id_fprivilege") ON DELETE CASCADE ON UPDATE CASCADE
;

ALTER TABLE "files" ADD CONSTRAINT "mimetypes_files" FOREIGN KEY ("id_mimetype") REFERENCES "mimetypes" ("id_mimetype") ON DELETE RESTRICT ON UPDATE CASCADE
;

ALTER TABLE "file_preferences" ADD CONSTRAINT "actions_file_preferences" FOREIGN KEY ("id_action") REFERENCES "actions" ("id_action") ON DELETE CASCADE ON UPDATE CASCADE
;

ALTER TABLE "file_preferences" ADD CONSTRAINT "mimetypes_file_preferences" FOREIGN KEY ("id_mimetype") REFERENCES "mimetypes" ("id_mimetype") ON DELETE CASCADE ON UPDATE CASCADE
;

ALTER TABLE "file_preferences" ADD CONSTRAINT "applications_file_preferences" FOREIGN KEY ("id_application") REFERENCES "applications" ("id_application") ON DELETE CASCADE ON UPDATE CASCADE
;

ALTER TABLE "file_preferences" ADD CONSTRAINT "users_file_preferences" FOREIGN KEY ("id_user") REFERENCES "users" ("id") ON DELETE CASCADE ON UPDATE CASCADE
;

ALTER TABLE "file_changes" ADD CONSTRAINT "files_file_changes" FOREIGN KEY ("id_file") REFERENCES "files" ("id_file") ON DELETE SET NULL ON UPDATE CASCADE
;

ALTER TABLE "file_changes" ADD CONSTRAINT "users_file_changes" FOREIGN KEY ("id_user") REFERENCES "users" ("id") ON DELETE SET NULL ON UPDATE CASCADE
;

ALTER TABLE "files" ADD CONSTRAINT "users_files_lock" FOREIGN KEY ("locked") REFERENCES "users" ("id") ON DELETE SET NULL ON UPDATE CASCADE
;

ALTER TABLE "files" ADD CONSTRAINT "file_parent" FOREIGN KEY ("id_parent") REFERENCES "files" ("id_file") ON DELETE RESTRICT ON UPDATE CASCADE
;
ALTER TABLE "files" ADD CONSTRAINT "file_storages_files" FOREIGN KEY ("id_files_storage") REFERENCES "files_storages" ("id_files_storage") ON DELETE RESTRICT ON UPDATE CASCADE
;

ALTER TABLE "applications_users" ADD CONSTRAINT "applications_users_applications" FOREIGN KEY ("id_application") REFERENCES "applications" ("id_application") ON DELETE CASCADE ON UPDATE CASCADE
;

ALTER TABLE "applications_users" ADD CONSTRAINT "applications_users_users" FOREIGN KEY ("id_user") REFERENCES "users" ("id") ON DELETE CASCADE ON UPDATE CASCADE
;




